<?php

defined( 'ABSPATH' ) || exit;
class Radio_Player_Admin
{
    /** @var null */
    private static  $instance = null ;
    public  $admin_pages = array() ;
    public function __construct()
    {
        add_action( 'admin_menu', [ $this, 'admin_menu' ] );
        add_action( 'admin_init', [ $this, 'init_update' ] );
        add_action( 'admin_notices', [ $this, 'display_notices' ] );
        add_action( 'wp_ajax_radio_player_hide_recommended_plugins', [ $this, 'hide_recommended_plugins' ] );
    }
    
    public function hide_recommended_plugins()
    {
        update_option( "radio_player_hide_recommended_plugin", true );
        wp_send_json_success();
    }
    
    public function display_notices()
    {
        //Rating notice if proxy notice is off
        
        if ( 'off' != get_option( 'radio_player_rating_notice' ) && 'off' != get_transient( 'radio_player_rating_notice_interval' ) ) {
            ob_start();
            include RADIO_PLAYER_INCLUDES . '/admin/views/notice/rating.php';
            $notice_html = ob_get_clean();
            radio_player()->add_notice( 'info  radio-player-rating-notice', $notice_html );
            return;
        }
    
    }
    
    public function init_update()
    {
        if ( !class_exists( 'Radio_Player_Update' ) ) {
            include_once RADIO_PLAYER_INCLUDES . '/admin/class-update.php';
        }
        $updater = Radio_Player_Update::instance();
        if ( $updater->needs_update() ) {
            $updater->perform_updates();
        }
    }
    
    /**
     * Add admin menu
     * @since 1.0.0
     */
    public function admin_menu()
    {
        $this->admin_pages['players_page'] = add_menu_page(
            __( 'Radio Player', 'radio-player' ),
            __( 'Radio Player', 'radio-player' ),
            'manage_options',
            'radio-player',
            [ $this, 'render_radio_player_page' ],
            RADIO_PLAYER_ASSETS . '/images/play.svg',
            59
        );
        // All players page
        $this->admin_pages['players_page'] = add_submenu_page(
            'radio-player',
            __( 'All Players', 'radio-player' ),
            __( 'All Players', 'radio-player' ),
            'manage_options',
            'radio-player'
        );
        // Getting started page
        $this->admin_pages['getting_started_page'] = add_submenu_page(
            'radio-player',
            __( 'Getting Started - Radio Player', 'radio-player' ),
            __( 'Getting Started', 'radio-player' ),
            'manage_options',
            'radio-player-getting-started',
            [ $this, 'render_getting_started_page' ]
        );
        // Settings page
        $this->admin_pages['settings_page'] = add_submenu_page(
            'radio-player',
            __( 'Settings - Radio Player', 'radio-player' ),
            __( 'Settings', 'radio-player' ),
            'manage_options',
            'radio-player-settings',
            [ $this, 'render_settings_page' ],
            10
        );
        // Recommended plugins page
        if ( empty(get_option( "radio_player_hide_recommended_plugin" )) ) {
            $this->admin_pages['recommended_plugins_page'] = add_submenu_page(
                'radio-player',
                esc_html__( 'Recommended Plugins', 'radio-player' ),
                esc_html__( 'Recommended Plugins', 'radio-player' ),
                'manage_options',
                'radio-player-recommended-plugins',
                [ $this, 'render_recommended_plugins_page' ]
            );
        }
    }
    
    public function render_recommended_plugins_page()
    {
        include RADIO_PLAYER_INCLUDES . '/admin/views/recommended-plugins.php';
    }
    
    public function render_radio_player_page()
    {
        echo  "<div id='radio-player-app'></div>" ;
    }
    
    /**
     * Get started page callback
     *
     * @since 1.0.0
     */
    public function render_getting_started_page()
    {
        include RADIO_PLAYER_INCLUDES . '/admin/views/getting-started/index.php';
    }
    
    public function render_settings_page()
    {
        ?>
        <script>
            const adminEmail = '<?php 
        echo  get_option( 'admin_email' ) ;
        ?>';

			<?php 
        ?>

        </script>

        <div id="radio-player-settings" class="radio-player-settings"></div>
	<?php 
    }
    
    /**
     * @return Radio_Player_Admin|null
     */
    public static function instance()
    {
        if ( is_null( self::$instance ) ) {
            self::$instance = new self();
        }
        return self::$instance;
    }

}
Radio_Player_Admin::instance();