<?php

defined( 'ABSPATH' ) || exit;
/**
 * Get metadata
 *
 * @param $post_id
 * @param $key
 * @param string $default
 *
 * @return mixed|string
 * @since 1.0.0
 */
function radio_player_get_meta( $post_id, $key, $default = '' )
{
    $meta = get_post_meta( $post_id, $key, true );
    return ( !empty($meta) ? $meta : $default );
}

function radio_player_get_stream_title( $stream_url )
{
    $result = '';
    if ( empty($stream_url) ) {
        return $result;
    }
    $icy_metaint = -1;
    $needle = 'StreamTitle=';
    $ua = 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/27.0.1453.110 Safari/537.36';
    $opts = array(
        'http' => array(
        'method'     => 'GET',
        'header'     => 'Icy-MetaData: 1',
        'user_agent' => $ua,
    ),
        "ssl"  => array(
        'allow_self_signed' => true,
        "verify_peer"       => false,
        "verify_peer_name"  => false,
    ),
    );
    $default = stream_context_set_default( $opts );
    if ( !($stream = @fopen( $stream_url, 'r' )) ) {
        return $result;
    }
    
    if ( $stream && ($meta_data = stream_get_meta_data( $stream )) && isset( $meta_data['wrapper_data'] ) ) {
        foreach ( $meta_data['wrapper_data'] as $header ) {
            
            if ( strpos( strtolower( $header ), 'icy-metaint' ) !== false ) {
                $tmp = explode( ":", $header );
                $icy_metaint = trim( $tmp[1] );
                break;
            }
        
        }
        
        if ( $icy_metaint != -1 ) {
            $buffer = stream_get_contents( $stream, 300, $icy_metaint );
            
            if ( strpos( $buffer, $needle ) !== false ) {
                $title = explode( $needle, $buffer );
                $title = trim( $title[1] );
                if ( $title !== '' ) {
                    $result = substr( $title, 1, strpos( $title, ';' ) - 2 );
                }
            }
        
        }
        
        if ( $stream ) {
            fclose( $stream );
        }
    }
    
    return $result;
}

function radio_player_get_setting( $key, $default = '' )
{
    $settings = radio_player_get_settings();
    if ( isset( $settings[$key] ) ) {
        return $settings[$key];
    }
    return $default;
}

function radio_player_get_user_ip()
{
    
    if ( !empty($_SERVER['HTTP_CLIENT_IP']) ) {
        //ip from share internet
        $ip = $_SERVER['HTTP_CLIENT_IP'];
    } elseif ( !empty($_SERVER['HTTP_X_FORWARDED_FOR']) ) {
        //ip pass from proxy
        $ip = $_SERVER['HTTP_X_FORWARDED_FOR'];
    } else {
        $ip = $_SERVER['REMOTE_ADDR'];
    }
    
    return $ip;
}

function radio_player_get_settings()
{
    $default_settings = [
        'httpPlayer'            => false,
        'volume'                => 80,
        'customPopupSize'       => false,
        'popupWidth'            => 420,
        'popupHeight'           => 330,
        'proxyURL'              => '',
        'excludeAll'            => false,
        'excludePages'          => [],
        'stickyStyle'           => 'fullwidth',
        'excludeExceptPages'    => [],
        'enableStats'           => false,
        'ads_report_recipients' => get_bloginfo( 'admin_email' ),
    ];
    $saved_settings = get_option( 'radio_player_settings', [] );
    $settings = array_merge( $default_settings, $saved_settings );
    return ( !empty($settings) ? $settings : $default_settings );
}

function radio_player_get_play_count( $post_id )
{
    global  $wpdb ;
    $sql = $wpdb->prepare( "SELECT SUM(`count`)  FROM {$wpdb->prefix}radio_player_statistics WHERE player_id = %d;", $post_id );
    $count = $wpdb->get_var( $sql );
    return intval( $count );
}

function radio_player_get_player( $id = false )
{
    global  $wpdb ;
    $table_name = $wpdb->prefix . 'radio_player_players';
    
    if ( $id ) {
        $player = $wpdb->get_row( $wpdb->prepare( "SELECT * FROM {$table_name} WHERE id = %d", $id ), ARRAY_A );
        return radio_player_get_formatted_player( $player );
    }
    
    $players = $wpdb->get_results( "SELECT * FROM {$table_name}", ARRAY_A );
    $formatted_players = [];
    if ( !empty($players) ) {
        foreach ( $players as $player ) {
            $formatted_players[] = radio_player_get_formatted_player( $player );
        }
    }
    if ( $id === 0 ) {
        return $formatted_players[0];
    }
    return $formatted_players;
}

function radio_player_get_formatted_player( $player )
{
    if ( empty($player) ) {
        return [];
    }
    $player['id'] = intval( $player['id'] );
    $player['status'] = filter_var( $player['status'], FILTER_VALIDATE_BOOLEAN );
    $player['config'] = unserialize( $player['config'] );
    $player['count'] = radio_player_get_play_count( $player['id'] );
    $player['locations'] = ( !empty($player['locations']) ? array_values( maybe_unserialize( $player['locations'] ) ) : [] );
    return $player;
}

function radio_player_get_stream_data( $url )
{
    $stream_data = [];
    // Get proxy stream data
    $meta_proxy = radio_player_get_setting( 'metadataProxy', false );
    
    if ( rp_fs()->can_use_premium_code__premium_only() && $meta_proxy ) {
        $proxy_url = 'https://199.192.19.73/proxy/?type=title&q=' . $url;
        $response = wp_remote_get( $proxy_url );
        if ( !is_wp_error( $response ) ) {
            $stream_data = wp_remote_retrieve_body( $response );
        }
    } else {
        
        if ( preg_match( '/(?<url>^https?:\\/\\/.*:\\d{4})/', $url, $match ) ) {
            // Try Shoutcast
            $response = wp_remote_get( $match['url'] . '/stats?sid=1&json=1' );
            $response_code = wp_remote_retrieve_response_code( $response );
            
            if ( !is_wp_error( $response ) && 200 == $response_code ) {
                $json = wp_remote_retrieve_body( $response );
                $meta = json_decode( $json );
                if ( !empty($meta) ) {
                    if ( !empty($meta->songtitle) ) {
                        $title = $meta->songtitle;
                    }
                }
            }
            
            // Try Icecast
            
            if ( empty($title) ) {
                $response = wp_remote_get( $match['url'] . '/status-json.xsl' );
                $response_code = wp_remote_retrieve_response_code( $response );
                
                if ( !is_wp_error( $response ) && 200 == $response_code ) {
                    $json = wp_remote_retrieve_body( $response );
                    $meta = json_decode( $json );
                    if ( !empty($meta) ) {
                        if ( !empty($meta->icestats->source->title) ) {
                            $title = $meta->icestats->source->title;
                        }
                    }
                }
            
            }
        
        } elseif ( preg_match( '/https?:\\/\\/streaming\\.live365\\.com\\/(?<id>[a-z0-9]+)/', $url, $match ) ) {
            
            if ( !empty($match['id']) ) {
                $response = wp_remote_get( 'https://live365.com/station/' . $match['id'] );
                $response_code = wp_remote_retrieve_response_code( $response );
                
                if ( !is_wp_error( $response ) && 200 == $response_code ) {
                    $html = wp_remote_retrieve_body( $response );
                    $dom = new DOMDocument();
                    @$dom->loadHTML( $html );
                    $xpath = new DOMXPath( $dom );
                    $title_wrap = $xpath->query( '//div[@class="jss27"]' );
                    $title = $title_wrap[0]->getElementsByTagName( 'p' )[0]->nodeValue;
                }
            
            }
        
        }
        
        if ( empty($title) ) {
            $title = radio_player_get_stream_title( $url );
        }
        if ( !empty($title) && strlen( $title ) > 3 ) {
            $stream_data['title'] = $title;
        }
    }
    
    return $stream_data;
}
